==> cyphermed-2.1.21-py3-none-any.whl: cyphermed/models/account_project_access_list.py <==
from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset


if TYPE_CHECKING:
    from ..models.project_access_schema import ProjectAccessSchema


T = TypeVar("T", bound="AccountProjectAccessList")


@_attrs_define
class AccountProjectAccessList:
    """List of project access granted to current account

    Attributes:
        project_access (Union[Unset, List['ProjectAccessSchema']]):
        page_count (Union[Unset, int]):
        object_count (Union[Unset, int]):
    """

    project_access: Union[Unset, List["ProjectAccessSchema"]] = UNSET
    page_count: Union[Unset, int] = UNSET
    object_count: Union[Unset, int] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        project_access: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.project_access, Unset):
            project_access = []
            for project_access_item_data in self.project_access:
                project_access_item = project_access_item_data.to_dict()
                project_access.append(project_access_item)

        page_count = self.page_count

        object_count = self.object_count

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if project_access is not UNSET:
            field_dict["project_access"] = project_access
        if page_count is not UNSET:
            field_dict["page_count"] = page_count
        if object_count is not UNSET:
            field_dict["object_count"] = object_count

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.project_access_schema import ProjectAccessSchema

        d = src_dict.copy()
        project_access = []
        _project_access = d.pop("project_access", UNSET)
        for project_access_item_data in _project_access or []:
            project_access_item = ProjectAccessSchema.from_dict(project_access_item_data)

            project_access.append(project_access_item)

        page_count = d.pop("page_count", UNSET)

        object_count = d.pop("object_count", UNSET)

        account_project_access_list = cls(
            project_access=project_access,
            page_count=page_count,
            object_count=object_count,
        )

        account_project_access_list.additional_properties = d
        return account_project_access_list

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> cyphermed-2.2.8-py3-none-any.whl: cyphermed/models/account_project_access_list.py <==
from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset


if TYPE_CHECKING:
    from ..models.account_project_access_schema import AccountProjectAccessSchema


T = TypeVar("T", bound="AccountProjectAccessList")


@_attrs_define
class AccountProjectAccessList:
    """List of project access granted to current account

    Attributes:
        project_access (Union[Unset, List['AccountProjectAccessSchema']]):
        project_ids (Union[Unset, List[str]]):
        page_count (Union[Unset, int]):
        object_count (Union[Unset, int]):
    """

    project_access: Union[Unset, List["AccountProjectAccessSchema"]] = UNSET
    project_ids: Union[Unset, List[str]] = UNSET
    page_count: Union[Unset, int] = UNSET
    object_count: Union[Unset, int] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        project_access: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.project_access, Unset):
            project_access = []
            for project_access_item_data in self.project_access:
                project_access_item = project_access_item_data.to_dict()
                project_access.append(project_access_item)

        project_ids: Union[Unset, List[str]] = UNSET
        if not isinstance(self.project_ids, Unset):
            project_ids = self.project_ids

        page_count = self.page_count

        object_count = self.object_count

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if project_access is not UNSET:
            field_dict["project_access"] = project_access
        if project_ids is not UNSET:
            field_dict["project_ids"] = project_ids
        if page_count is not UNSET:
            field_dict["page_count"] = page_count
        if object_count is not UNSET:
            field_dict["object_count"] = object_count

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.account_project_access_schema import AccountProjectAccessSchema

        d = src_dict.copy()
        project_access = []
        _project_access = d.pop("project_access", UNSET)
        for project_access_item_data in _project_access or []:
            project_access_item = AccountProjectAccessSchema.from_dict(project_access_item_data)

            project_access.append(project_access_item)

        project_ids = cast(List[str], d.pop("project_ids", UNSET))

        page_count = d.pop("page_count", UNSET)

        object_count = d.pop("object_count", UNSET)

        account_project_access_list = cls(
            project_access=project_access,
            project_ids=project_ids,
            page_count=page_count,
            object_count=object_count,
        )

        account_project_access_list.additional_properties = d
        return account_project_access_list

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
